Django DMARC — Django DMARC 0.3.1 documentation

# Django DMARC

Making it easier to manage DMARC reports

Designed to quickly and easily import DMARC reports.

## Contents

- Documentation
- Change Log

### Quick start

1. Install the app

2. Add “dmarc” to your INSTALLED_APPS setting:

       INSTALLED_APPS = (
           ...
           'dmarc',
       )

3. Add dmarc.urls to your urls:

       from dmarc import urls as dmarc_urls

       urlpatterns = [
           ...
           url(r"^dmarc/", include(dmarc_urls)),
       ]

4. Run ‘python manage.py migrate’ to create the database models.

5. Import a report with:

       python manage.py importdmarcreport --email

6. See your aggregated feedback reports from the Admin page at admin/dmarc

## Copyright

Django DMARC and this documentation is Copyright (c) 2015-2016, Persistent Objects Ltd. All rights reserved.

## License

This documentation is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/.

The software is licensed under the BSD two clause license.

Copyright (c) 2015-2016, Persistent Objects Ltd. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

> Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

> Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY PERSISTENT OBJECTS LTD AND CONTRIBUTORS ‘AS IS’ AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FREEBSD PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the authors and should not be interpreted as representing official policies, either expressed or implied, of Persistent Objects Ltd.